@@ -13,11 +13,11 @@ def decode_token(token, key, exp=3600):
     return data
 
 
-def make_token(data: dict, key, exp=3600) -> str:
+def make_token(data: dict, key, exp=3600) -> dict:
     now_t = time.time()
     data["exp"] = int(int(now_t) + exp)
-    token = jwt.encode(data, key, algorithm='HS256')
-    return str(token)
+    data["token"]=jwt.encode(data, key, algorithm='HS256')
+    return data
 
 
 if __name__ == '__main__':
